.. _core_device_admin_tasks:

Admin Tasks
-----------

This section describes how to perform administration tasks for the Device plugin.

Device Management
`````````````````

:Type: The type of device accessing the services.
:Description: The name of the device entered when enrolled.
:Last Online: The last time the device connected to the server.
:Enrollment: This is where you can toggle a devices enrollment.
:Offline Cache: This toggles a devices ability to cache data for offline use.
:Current Location: The coordinates of the devices if supplied.

Searching for Devices
`````````````````````
To search for a devices in the database:

#. Click on the Search Icon.
#. Enter a name in the text box.

.. image::device_search.png
    :align: center

Display the Offline Cache Status
````````````````````````````````

Click on the **Question Mark** icon next to the Offline Cache Toggle.

.. image::offline_cache_info.png
    :align: center

Enrolling Devices
`````````````````

The enrolled devices are displayed to the administrator via the admin UI.
To enroll or unenroll devices:

Open the Peek Admin UI and navigate to the Device plugin.

----

#.  Click on the **Device** tab.
#.  Toggle the **Enrollment** button.


.. image:: admin_task_devices.png

----

The user will see their device toggle from the "Waiting for enrollment" to the Peek
home screen.

Deleting Devices
````````````````
To delete a device, click the subtract icon to the right of Enrollment Status.